@@ -47,16 +47,17 @@ class Hx():
         return cang_df
     #用最新价格更新持仓
     def updata_cang(self,cang_df):
+        if cang_df.empty:return cang_df
         temp_list = []
         for code in cang_df['证券代码'].values:
             if code[:2]=='11':code='sh'+code
             else:code='sz'+code
             temp_list.append(self.get_real_data(code)['price'])
         cang_df['市价']=temp_list
-        cang_df['成本值']=cang_df['成本价']*cang_df['股票余额']
-        cang_df['市值']=cang_df['市价']*cang_df['股票余额']
-        cang_df['盈亏']=cang_df['市值']-cang_df['成本值']
-        cang_df['盈亏(%)']=round((cang_df['市值']-cang_df['成本值'])/cang_df['成本值']*100,2)  #round((data['price']-data['close'])/data['close']*100,2)
+        #cang_df['成本值']=cang_df['成本价']*cang_df['可用余额']
+        cang_df['新市值']=cang_df['市价']*cang_df['可用余额']
+        cang_df['盈亏']=cang_df['新市值']-cang_df['市值']
+        cang_df['盈亏比(%)']=round((cang_df['新市值']-cang_df['市值'])/cang_df['市值']*100,2)  
         cang_df=cang_df.round(2)
         return cang_df
     #获取资金
@@ -73,6 +74,13 @@ class Hx():
         left_window.select('\\双向委托')
         main_window.type_keys('{F6}')
         return d
+    #获取资金
+    def get_kymoney(self):
+        global hwnd
+        kymoney_hwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='msctls_statusbar32', parent=hwnd)[0]
+        kymoney_window = pywinauto.controls.common_controls.StatusBarWrapper(kymoney_hwnd)
+        kymoney = kymoney_window.texts()[5]
+        return kymoney
     #异常处理 弹窗
     def close_pop(self):
         global app
@@ -137,7 +145,7 @@ class Hx():
                 time.sleep(0.3)
     #梭哈
     def soha(self,n=20):
-        money = float(self.get_money()['可用余额'])/n
+        money = float(self.get_kymoney())/n
         data = self.get_kzz_list()
         zz_list = list(data['转债代码'].values[:n])
         print(zz_list)
@@ -224,4 +232,3 @@ class Hx():
         d['zt_price'] = float(html[47]);d['liangbi'] = float(html[49]) #量比
         d['dt']=html[30]
         return d
-
